@@ -3,9 +3,9 @@ package Devel::GlobalDestruction;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
-use Sub::Exporter -setup => {
+use Sub::Exporter::Progressive -setup => {
     exports => [ qw(in_global_destruction) ],
     groups  => { default => [ -all ] },
 };
@@ -119,7 +119,8 @@ destruction is in effect.
 
 =head1 EXPORTS
 
-This module uses L<Sub::Exporter> so the exports may be renamed, aliased, etc.
+This module uses L<Sub::Exporter::Progressive> so the exports may be renamed,
+aliased, etc. if L<Sub::Exporter> is present.
 
 =over 4
 
@@ -141,6 +142,8 @@ Jesse Luehrs E<lt>doy@tozt.netE<gt>
 
 Peter Rabbitson E<lt>ribasushi@cpan.orgE<gt>
 
+Arthur Axel 'fREW' Schmidt E<lt>frioux@gmail.comE<gt>
+
 =head1 COPYRIGHT
 
     Copyright (c) 2008 Yuval Kogman. All rights reserved
